@@ -1,13 +1,12 @@
+import argparse
 import fractions
+import functools
 import math
 import operator
-import functools
-import sys
 import os
-import argparse
-import textwrap
 import shutil
-import phidnet
+import sys
+import textwrap
 
 
 def matrix(*pargs, **kwargs):   # convert to matrix class.
@@ -31,11 +30,11 @@ def cross(u, v):   # Returns u x v - the vector product of 3D column vectors u a
 
 
 
-
 class MatrixError(Exception):
     pass
 
 
+
 class Matrix:
 
     def __init__(self, rows, cols, fill=0):   # Initialize a `rows` x `cols` matrix filled with `fill`
@@ -43,6 +42,8 @@ class Matrix:
         self.numcols = cols
         self.grid = [[fill for i in range(cols)] for j in range(rows)]
 
+
+
     def __str__(self):   # Returns a string representation of the matrix
         maxlen = max(len(str(e)) for _, _, e in self)
         string = 'matrix( \n' + '\n'.join(
@@ -51,38 +52,48 @@ class Matrix:
         string = string + "\n)\n"
         return textwrap.dedent(string)
 
+
+
     def __repr__(self):   # Returns a string representation of the object
         return '<%s %sx%s 0x%x>' % (
             self.__class__.__name__, self.numrows, self.numcols, id(self)
         )
 
-    def __getitem__(self, key):
-        """ Enables `self[row][col]` indexing and assignment. """
+
+
+    def __getitem__(self, key):   # Enables `self[row][col]` indexing and assignment.
         return self.grid[key]
 
-    def __contains__(self, item):
-        """ Containment: `item in self`. """
+
+
+    def __contains__(self, item):   # Containment: `item in self`.
         for _, _, element in self:
             if element == item:
                 return True
         return False
 
-    def __neg__(self):
-        """ Negative operator: `- self`. Returns a negated copy. """
+
+
+    def __neg__(self):   # Negative operator: `- self`. Returns a negated copy.
         return self.map(lambda element: -element)
 
-    def __pos__(self):
-        """ Positive operator: `+ self`. Returns a copy. """
+
+
+    def __pos__(self):   # Positive operator: `+ self`. Returns a copy.
         return self.map(lambda element: element)
 
-    def __eq__(self, other):
-        """ Equality: `self == other`. """
+
+
+    def __eq__(self, other):   # Equality: `self == other`.
         return self.equals(other)
 
-    def __ne__(self, other):
-        """ Inequality: `self != other`. """
+
+
+    def __ne__(self, other):   # Inequality: `self != other`.
         return not self.__eq__(other)
 
+
+
     def __add__(self, other):   # self + other
         if type(other) != Matrix:   # matrix + scalar
             m = Matrix(self.numrows, self.numcols)
@@ -99,6 +110,8 @@ class Matrix:
                 m[row][col] = element + other[row][col]
             return m
 
+
+
     def __sub__(self, other):   # self - other
         if type(other) != Matrix:   # matrix - scalar
             m = Matrix(self.numrows, self.numcols)
@@ -116,6 +129,7 @@ class Matrix:
             return m
 
 
+
     def __mul__(self, other):   # self * other
         if type(other) != Matrix:   # matrix * scalar
             m = Matrix(self.numrows, self.numcols)
@@ -133,6 +147,7 @@ class Matrix:
             return m
 
 
+
     def __truediv__(self, other):   # self / other
         if type(other) != Matrix:   # matrix / scalar
             m = Matrix(self.numrows, self.numcols)
@@ -151,8 +166,7 @@ class Matrix:
 
 
 
-    def __pow__(self, other):
-        """ Exponentiation: `self ** other`. """
+    def __pow__(self, other):   # Exponentiation: `self ** other`.
         if other >= 1:
             m = self.copy()
             for i in range(other - 1):
@@ -182,7 +196,6 @@ class Matrix:
 
 
 
-
     def __lt__(self, other):
         if type(other) != Matrix:   # matrix  scalar
             m = Matrix(self.numrows, self.numcols)
@@ -200,6 +213,7 @@ class Matrix:
             return m
 
 
+
     def __le__(self, other):
         if type(other) != Matrix:   # matrix  scalar
             m = Matrix(self.numrows, self.numcols)
@@ -217,6 +231,7 @@ class Matrix:
             return m
 
 
+
     def __ge__(self, other):
         if type(other) != Matrix:   # matrix  scalar
             m = Matrix(self.numrows, self.numcols)
@@ -235,7 +250,6 @@ class Matrix:
 
 
 
-
     def __iter__(self):
         """ Iteration: `for row, col, element in self`. """
         for row in range(self.numrows):
@@ -243,6 +257,7 @@ class Matrix:
                 yield row, col, self[row][col]
 
 
+
     def div_by(self, d):   # return d / self
         m = Matrix(self.numrows, self.numcols)
         for row, col, element in self:
@@ -250,6 +265,7 @@ class Matrix:
         return m
 
 
+
     def to_list(self):
         li = []
         for row in range(self.numrows):
@@ -257,6 +273,7 @@ class Matrix:
         return li
 
 
+
     def exp(self):
         if type(self) != Matrix:
             return math.exp(self)
@@ -267,6 +284,7 @@ class Matrix:
             return m
 
 
+
     def argmax(self):
         max = self[0][0]
         for row in range(self.numrows):
@@ -280,6 +298,7 @@ class Matrix:
             return maxIdx
 
 
+
     def max(self):
         max = self[0][0]
         for row in range(self.numrows):
@@ -290,7 +309,6 @@ class Matrix:
 
 
 
-
     def log(self):
         if type(self) != Matrix:
             return math.log(self)
@@ -300,6 +318,8 @@ class Matrix:
                 m[row][col] = math.log(self[row][col])
             return m
 
+
+
     def slice(self, s1, e1, s2, e2):
         sliced = []
         mat = self.to_list()
@@ -312,47 +332,51 @@ class Matrix:
             sliced[index] = sliced[index][s2:e2 + 1]
             index += 1
 
-        return phid.matrix.matrix(sliced)
+        return matrix(sliced)
 
-    def row(self, n):
-        """ Returns an iterator over the specified row. """
+
+
+    def row(self, n):   # Returns an iterator over the specified row.
         for col in range(self.numcols):
             yield self[n][col]
 
-    def col(self, n):
-        """ Returns an iterator over the specified column. """
+
+
+    def col(self, n):   # Returns an iterator over the specified column.
         for row in range(self.numrows):
             yield self[row][n]
 
-    def rows(self):
-        """ Returns a row iterator for each row in the matrix. """
+
+
+    def rows(self):   # Returns a row iterator for each row in the matrix.
         for row in range(self.numrows):
             yield self.row(row)
 
-    def cols(self):
-        """ Returns a column iterator for each column in the matrix. """
+
+
+    def cols(self):   # Returns a column iterator for each column in the matrix.
         for col in range(self.numcols):
             yield self.col(col)
 
-    def rowvec(self, n):
-        """ Returns the specified row as a new row vector. """
+
+
+    def rowvec(self, n):   # Returns the specified row as a new row vector.
         v = Matrix(1, self.numcols)
         for col in range(self.numcols):
             v[0][col] = self[n][col]
         return v
 
-    def colvec(self, n):
-        """ Returns the specified column as a new column vector. """
+
+
+    def colvec(self, n):   # Returns the specified column as a new column vector.
         v = Matrix(self.numrows, 1)
         for row in range(self.numrows):
             v[row][0] = self[row][n]
         return v
 
-    def equals(self, other, delta=None):
-        """ Returns true if `self` and `other` are identically-sized matrices
-        and their corresponding elements agree to within `delta`. If `delta`
-        is omitted, we perform a simple equality check (`==`) on corresponding
-        elements instead. """
+
+
+    def equals(self, other, delta=None):   # Returns true if `self` and `other` are identically-sized matrices and their corresponding elements agree to within `delta`. If `delta` is omitted, we perform a simple equality check (`==`) on corresponding elements instead.
         if self.numrows != other.numrows or self.numcols != other.numcols:
             return False
         if delta:
@@ -365,19 +389,22 @@ class Matrix:
                     return False
         return True
 
-    def copy(self):
-        """ Returns a copy of the matrix. """
+
+
+    def copy(self):   # Returns a copy of the matrix.
         return self.map(lambda element: element)
 
-    def trans(self):
-        """ Returns the transpose of the matrix as a new object. """
+
+
+    def trans(self):   # Returns the transpose of the matrix as a new object.
         m = Matrix(self.numcols, self.numrows)
         for row, col, element in self:
             m[col][row] = element
         return m
 
-    def det(self):
-        """ Returns the determinant of the matrix. """
+
+
+    def det(self):   # Returns the determinant of the matrix.
         if not self.is_square():
             raise MatrixError('non-square matrix does not have determinant')
         ref, _, multiplier = get_row_echelon_form(self)
@@ -387,27 +414,32 @@ class Matrix:
         )
         return ref_det / multiplier
 
-    def minor(self, row, col):
-        """ Returns the specified minor. """
+
+
+    def minor(self, row, col):   # Returns the specified minor.
         return self.del_row_col(row, col).det()
 
-    def cofactor(self, row, col):
-        """ Returns the specified cofactor. """
+
+
+    def cofactor(self, row, col):   # Returns the specified cofactor.
         return pow(-1, row + col) * self.minor(row, col)
 
-    def cofactors(self):
-        """ Returns the matrix of cofactors as a new object. """
+
+
+    def cofactors(self):   # Returns the matrix of cofactors as a new object.
         m = Matrix(self.numrows, self.numcols)
         for row, col, element in self:
             m[row][col] = self.cofactor(row, col)
         return m
 
-    def adjoint(self):
-        """ Returns the adjoint matrix as a new object. """
+
+
+    def adjoint(self):   # Returns the adjoint matrix as a new object.
         return self.cofactors().trans()
 
-    def inv(self):
-        """ Returns the inverse matrix if it exists or raises MatrixError. """
+
+
+    def inv(self):   # Returns the inverse matrix if it exists or raises MatrixError.
         if not self.is_square():
             raise MatrixError('non-square matrix cannot have an inverse')
         identity = Matrix.identity(self.numrows)
@@ -416,12 +448,14 @@ class Matrix:
             raise MatrixError('matrix is non-invertible')
         return inverse
 
-    def del_row_col(self, row_to_delete, col_to_delete):
-        """ Returns a new matrix with the specified row & column deleted. """
+
+
+    def del_row_col(self, row_to_delete, col_to_delete):   # Returns a new matrix with the specified row & column deleted.
         return self.del_row(row_to_delete).del_col(col_to_delete)
 
-    def del_row(self, row_to_delete):
-        """ Returns a new matrix with the specified row deleted. """
+
+
+    def del_row(self, row_to_delete):   # Returns a new matrix with the specified row deleted.
         m = Matrix(self.numrows - 1, self.numcols)
         for row, col, element in self:
             if row < row_to_delete:
@@ -430,8 +464,9 @@ class Matrix:
                 m[row - 1][col] = element
         return m
 
-    def del_col(self, col_to_delete):
-        """ Returns a new matrix with the specified column deleted. """
+
+
+    def del_col(self, col_to_delete):   # Returns a new matrix with the specified column deleted.
         m = Matrix(self.numrows, self.numcols - 1)
         for row, col, element in self:
             if col < col_to_delete:
@@ -440,58 +475,69 @@ class Matrix:
                 m[row][col - 1] = element
         return m
 
-    def map(self, func):
-        """ Forms a new matrix by mapping `func` to each element. """
+
+
+    def map(self, func):   # Forms a new matrix by mapping `func` to each element.
         m = Matrix(self.numrows, self.numcols)
         for row, col, element in self:
             m[row][col] = func(element)
         return m
 
-    def rowop_multiply(self, row, m):
-        """ In-place row operation. Multiplies the specified row by `m`. """
+
+
+    def rowop_multiply(self, row, m):   # In-place row operation. Multiplies the specified row by `m`.
         for col in range(self.numcols):
             self[row][col] = self[row][col] * m
 
-    def rowop_swap(self, r1, r2):
-        """ In-place row operation. Interchanges the two specified rows. """
+
+
+    def rowop_swap(self, r1, r2):   # In-place row operation. Interchanges the two specified rows.
         for col in range(self.numcols):
             self[r1][col], self[r2][col] = self[r2][col], self[r1][col]
 
-    def rowop_add(self, r1, m, r2):
-        """ In-place row operation. Adds `m` times row `r2` to row `r1`. """
+
+
+    def rowop_add(self, r1, m, r2):   # In-place row operation. Adds `m` times row `r2` to row `r1`.
         for col in range(self.numcols):
             self[r1][col] = self[r1][col] + m * self[r2][col]
 
-    def ref(self):
-        """ Returns the row echelon form of the matrix. """
+
+
+    def ref(self):   # Returns the row echelon form of the matrix.
         return get_row_echelon_form(self)[0]
 
-    def rref(self):
-        """ Returns the reduced row echelon form of the matrix. """
+
+
+    def rref(self):   # Returns the reduced row echelon form of the matrix.
         return get_reduced_row_echelon_form(self)[0]
 
-    def len(self):
-        """ Vectors only. Returns the length of the vector. """
+
+
+    def len(self):   # Vectors only. Returns the length of the vector.
         return math.sqrt(sum(e ** 2 for _, _, e in self))
 
-    def dir(self):
-        """ Vectors only. Returns a unit vector in the same direction. """
+
+
+    def dir(self):   # Vectors only. Returns a unit vector in the same direction.
         return (1 / self.len()) * self
 
-    def is_square(self):
-        """ True if the matrix is square. """
+
+
+    def is_square(self):   # True if the matrix is square.
         return self.numrows == self.numcols
 
-    def is_invertible(self):
-        """ True if the matrix is invertible. """
+
+
+    def is_invertible(self):   # True if the matrix is invertible.
         try:
             inverse = self.inv()
             return True
         except MatrixError:
             return False
 
-    def rank(self):
-        """ Returns the rank of the matrix. """
+
+
+    def rank(self):   # Returns the rank of the matrix.
         rank = 0
         for row in self.ref().rows():
             for element in row:
@@ -501,8 +547,8 @@ class Matrix:
         return rank
 
 
-    def dot(self, other):
-        """ Multiplication: `dot(self, other)`.  행렬곱"""
+
+    def dot(self, other):   # Multiplication: `dot(self, other)`.
         if isinstance(other, Matrix):
             if self.numcols != other.numrows:
                 raise MatrixError('incompatible sizes for multiplication')
@@ -515,6 +561,7 @@ class Matrix:
             return self.map(lambda element: element * other)
 
 
+
     def sum(self):
         sum = 0
         for row, col, element in self:
@@ -523,29 +570,30 @@ class Matrix:
 
 
 
-    def cross(self, other):
-        """ Returns the vector product: `self` x `other`. """
+    def cross(self, other):   # Returns the vector product: `self` x `other`.
         return cross(self, other)
 
-    def elements(self):
-        """ Returns an iterator over the matrix's elements. """
+
+
+    def elements(self):   # Returns an iterator over the matrix's elements.
         for row in range(self.numrows):
             for col in range(self.numcols):
                 yield self[row][col]
 
 
+
     @staticmethod
-    def from_list(l):
-        """ Instantiates a new matrix object from a list of lists. """
+    def from_list(l):   # Instantiates a new matrix object from a list of lists.
         m = Matrix(len(l), len(l[0]))
         for rownum, row in enumerate(l):
             for colnum, element in enumerate(row):
                 m[rownum][colnum] = element
         return m
 
+
+
     @staticmethod
-    def from_string(s, rowsep=None, colsep=None, parser=fractions.Fraction):
-        """ Instantiates a new matrix object from a string. """
+    def from_string(s, rowsep=None, colsep=None, parser=fractions.Fraction):   # Instantiates a new matrix object from a string.
         rows = s.strip().split(rowsep) if rowsep else s.strip().splitlines()
         m = Matrix(len(rows), len(rows[0].split(colsep)))
         for rownum, row in enumerate(rows):
@@ -553,20 +601,23 @@ class Matrix:
                 m[rownum][colnum] = parser(element)
         return m
 
+
+
     @staticmethod
-    def identity(n):
-        """ Instantiates a new n x n identity matrix. """
+    def identity(n):   # Instantiates a new n x n identity matrix.
         m = Matrix(n, n)
         for i in range(n):
             m[i][i] = 1
         return m
 
 
+
 # --------------------------------------------------------------------------
 # Algorithms
 # --------------------------------------------------------------------------
 
 
+
 # We determine the row echelon form of the matrix using the forward phase of
 # the Gauss-Jordan elimination algorithm. If a `mirror` matrix is supplied,
 # we apply the same sequence of row operations to it. Note that neither
@@ -619,6 +670,7 @@ def get_row_echelon_form(matrix, mirror=None):
     return matrix, mirror, det_multiplier
 
 
+
 # Determine the reduced row echelon form of the matrix using the Gauss-Jordan
 # elimination algorithm. If a `mirror` matrix is supplied, the same sequence
 # of row operations will be applied to it. Note that neither matrix is
@@ -645,11 +697,13 @@ def get_reduced_row_echelon_form(matrix, mirror=None):
     return matrix, mirror
 
 
+
 # --------------------------------------------------------------------------
 # CLI
 # --------------------------------------------------------------------------
 
 
+
 # Command line helptext.
 helptext = """
 Usage: %s [OPTIONS] [FLAGS]
@@ -666,6 +720,7 @@ Flags:
 """ % os.path.basename(sys.argv[0])
 
 
+
 # Custom argparse action to override the default help text.
 class HelpAction(argparse.Action):
     def __call__(self, parser, namespace, values, option_string=None):
@@ -673,6 +728,7 @@ class HelpAction(argparse.Action):
         sys.exit()
 
 
+
 # Read in a matrix interactively from the terminal.
 def terminal_input():
     termcols, _ = shutil.get_terminal_size()
@@ -689,6 +745,7 @@ def terminal_input():
     return '\n'.join(lines)
 
 
+
 # Analyse a matrix and print a report.
 def analyse(matrix):
     rows, cols, rank = matrix.numrows, matrix.numcols, matrix.rank()
@@ -721,6 +778,7 @@ def analyse(matrix):
     print('\n' + '─' * termcols)
 
 
+
 # Entry point for the command line interface.
 def main():
     parser = argparse.ArgumentParser(add_help=False)
@@ -756,5 +814,6 @@ def main():
         sys.exit('Error: unknown parser argument.')
 
 
+
 if __name__ == '__main__':
     main()
\ No newline at end of file
